@@ -1,6 +1,6 @@
 #!/usr/pkg/bin/texlua
 --
---  $Id: luafindfont.lua 735 2023-06-22 19:12:29Z herbert $
+--  $Id: luafindfont.lua 1072 2025-02-14 12:45:31Z herbert $
 -----------------------------------------------------------------------
 --         FILE:  luafindfont.lua
 --  DESCRIPTION:  search for fonts in the database
@@ -8,7 +8,7 @@
 --       AUTHOR:  Herbert Voß  (C) 2023-06-21
 -----------------------------------------------------------------------
         luafindfont = luafindfont or { }
-      local version = 0.13
+      local version = 0.15
 luafindfont.version = version
 
 --[[
@@ -31,6 +31,7 @@ Report bugs to  hvoss@tug.org
 
 ]]
 
+-- equivilant with ConTeXt, e.g. times
 -- mtxrun --script font --list --name --all --pattern=times
 
 kpse.set_program_name("luatex")
@@ -38,8 +39,6 @@ local f = kpse.find_file("lualibs.lua")
 
 require("lualibs")  -- all part of LuaTeX
 
---require("luafindfont-utflib")
-
 if #arg == 0 then
   print("I need at least one argument or option! Will exit ...")
   os.exit()
@@ -49,6 +48,7 @@ local args_verbose = 0
 local args_nosymbolicnames = false
 local args_otfinfo = 0
 local args_info = 0
+local args_listonly = 0
 local args_xetex = 0
 local args_max_string = 90
 
@@ -71,6 +71,8 @@ while i <= #arg do
     -o,--otfinfo (default 0)
     -i,--info (default 0)
     -I,--Info (default 0)
+    -l, --listonlynames
+    -L, --listonlyfiles
     -x, --xetex 
     -v, --verbose
     -V, --version
@@ -83,6 +85,10 @@ while i <= #arg do
     args_verbose = 1
   elseif (arg[i] == "-n") or (arg[i] == "--nosymbolicnames") or (arg[i] == "--no-symbolic-names") then
     args_nosymbolicnames = true
+  elseif arg[i] == "-l" or arg[i] == "--listonlynames" then
+    args_listonly = 1
+  elseif arg[i] == "-L" or arg[i] == "--listonlyfiles" then
+    args_listonly = 2
   elseif arg[i] == "-x" or arg[i] == "--xetex" then
     args_xetex = 1
   elseif arg[i] == "-o" or arg[i] == "--otfinfo" then
@@ -147,7 +153,7 @@ if vlevel > 0 then
   print("  args_max_string = "..args_max_string)
 end
   
-if not args_font then
+if not args_font and args_listonly < 1 then
   print("No fontname given, will close ...")
   os.exit()
 end
@@ -157,7 +163,10 @@ local info = args_info
 local Info = args_Info
 local noSymbolicNames = args_nosymbolicnames
 local maxStrLength = args_max_string
-local font_str = args_font:lower():gsub("%s+", ""):split("&")
+local font_str = {}
+if args_listonly < 1 then
+  font_str = args_font:lower():gsub("%s+", ""):split("&")
+end
 if #font_str == 1 then font_str[2] = "" end
 
 local luaVersion = _VERSION
@@ -282,6 +291,13 @@ function compareEntries(f1, f2)
   end
 end
 
+function centerText(text, width)
+  if text == nil then return "" end
+  local spaces = math.floor((width-string.len(text))/2)
+  local len = string.len(text)
+  return ((" "):rep(spaces)..text..(" "):rep(spaces))
+end
+
 local fontData = {}
 local fontListFile = getFileLocation()
 if fontListFile == "" then
@@ -305,6 +321,29 @@ end
 
 --print(require 'xindex-pretty'.dump(fontData)) --["families"]["system"]["otf"]))
 
+if args_listonly == 1 then
+  local tmp = {}
+  for _,font in ipairs(fontData.mappings) do
+    tmp[#tmp + 1] = font.fontname --.. " (" .. font.basename .. ")"
+  end
+  table.sort(tmp)
+  for _,fontname in ipairs(tmp) do
+    print(fontname)
+  end
+  os.exit()
+elseif args_listonly == 2 then 
+  local tmp = {}
+  for _,font in ipairs(fontData.mappings) do
+    tmp[#tmp + 1] = font.basename
+  end
+  table.sort(tmp)
+  for _,filename in ipairs(tmp) do
+    print(filename)
+  end
+  os.exit()
+end
+
+
 fontDataMap = fontData["mappings"]
 fontFilesTable = fontData["files"]["full"]
 
@@ -375,20 +414,38 @@ if l_max[3] > maxStrLength then l_max[3] = maxStrLength end
 local minChars = 26
 local Fontname = "Filename"
 local Path = "Path"
-local SymbolicName = "Symbolic name"
+local SymbolicName = "Symbolic"
 local lfdNr = "No."
 
 if (font_str ~= "*") and not noSymbolicNames then
   if args_xetex > 0 then
-    print(string.format("%5s %"..l_max[1].."s %"..l_max[2].."s  %"..l_max[3].."s".."%4s",lfdNr,Fontname,SymbolicName,Path,"X")) 
+--    print(string.format("%5s %"..l_max[1].."s %"..l_max[2].."s  %"..l_max[3].."s".."%4s",lfdNr,Fontname,SymbolicName,Path,"X")) 
+    io.write(string.format("%5s",lfdNr))
+    io.write(centerText(Fontname,l_max[1]))
+    io.write(centerText(SymbolicName,l_max[2]))
+    io.write(centerText(Path,l_max[3]))
+    print("X") 
   else      
-    print(string.format("%5s %"..l_max[1].."s %"..l_max[2].."s  %"..l_max[3].."s",lfdNr,Fontname,SymbolicName,Path)) 
+--    print(string.format("%5s %"..l_max[1].."s %"..l_max[2].."s  %"..l_max[3].."s",lfdNr,Fontname,SymbolicName,Path)) 
+    io.write(string.format("%5s",lfdNr))
+    io.write(centerText(Fontname,l_max[1]))
+    io.write(centerText(SymbolicName,l_max[2]))
+    print(centerText(Path,l_max[3]))
   end
 else
   if args_xetex > 0 then
-    print(string.format("%5s %"..l_max[1].."s  %"..l_max[3].."s".."%4s",lfdNr,Fontname,Path,"X")) 
+--    print(string.format("%5s %"..l_max[1].."s  %"..l_max[3].."s".."%4s",lfdNr,Fontname,Path,"X")) 
+    io.write(string.format("%5s",lfdNr))
+    io.write(centerText(Fontname,l_max[1]))
+    io.write(centerText(SymbolicName,l_max[2]))
+    io.write(centerText(Path,l_max[3]))
+    print("X")
   else
-    print(string.format("%5s %"..l_max[1].."s  %"..l_max[3].."s",lfdNr,Fontname,Path)) 
+--    print(string.format("%5s %"..l_max[1].."s  %"..l_max[3].."s",lfdNr,Fontname,Path)) 
+    io.write(string.format("%5s",lfdNr))
+    io.write(centerText(Fontname,l_max[1]))
+    io.write(centerText(SymbolicName,l_max[2]))
+    print(centerText(Path,l_max[3]))
   end
 end
 
